// |reftest| pref(javascript.options.xml.content,true) skip -- obsolete test
/* -*- Mode: java; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */


START("9.2.1.7 XMLList [[DeepCopy]]");

var actual = 'Test not implemented';
var expect = 'PASS';

TEST(1, expect, actual);

END();

